@@ -1,7 +1,7 @@
 /*
  * Squashfs
  *
- * Copyright (c) 2024, 2025
+ * Copyright (c) 2024, 2025, 2026
  * Phillip Lougher <phillip@squashfs.org.uk>
  *
  * This program is free software; you can redistribute it and/or
@@ -77,8 +77,8 @@ static char *mksquashfs_options[]={
 	"-action-file", "-log-action-file", "-true-action-file",
 	"-false-action-file", "", "", "",
 	/* tar options */
-	"-default-mode", "-default-uid", "-default-gid", "-ignore-zeros", "",
-	"", "",
+	"-default-mode", "-default-uid", "-default-gid", "-ignore-zeros",
+	"-numeric-owner", "", "", "",
 	/* expert options */
 	"-stream", "-fix", "-nopad", "-offset", "-o", "", "", "",
 	/* help options */
@@ -104,7 +104,8 @@ static char *sqfstar_options[]={
 	/* permissions options */
 	"-all-root", "-root-mode", "-root-uid", "-root-gid", "-force-file-mode",
 	"-force-dir-mode", "-force-uid", "-force-gid", "-uid-gid-offset",
-	"-default-mode", "-default-uid", "-default-gid", "", "", "",
+	"-default-mode", "-default-uid", "-default-gid", "-numeric-owner", "",
+	"", "",
 	/* pseudo options */
 	"-p", "-pd", "-pd", "-pf", "-pseudo-override", "", "", "",
 	/* xattr options */
@@ -154,7 +155,7 @@ static char *mksquashfs_args[]={
 	"<action@expression>", "<file>", "<file>", "<file>", "<file>", "", "",
 	"",
 	/* tar options */
-	"<mode>", "<value>", "<value>", "", "", "", "",
+	"<mode>", "<value>", "<value>", "", "", "", "", "",
 	/* expert options */
 	"", "<filesystem>", "", "<offset>", "<offset>", "", "", "",
 	/* help options */
@@ -173,7 +174,7 @@ static char *sqfstar_args[]={
 	"<time>", "<time>", "<time>", "", "<time>", "", "", "",
 	/* permissions options */
 	"", "<mode>", "<user>", "<group>", "<mode>", "<mode>", "<user>",
-	"<group>", "<value>", "<mode>", "<user>", "<roup>", "", "", "",
+	"<group>", "<value>", "<mode>", "<user>", "<group>", "", "", "", "",
 	/* pseudo options */
 	"<pseudo-definition>", "<d mode uid gid>", "<D time mode u g>",
 	"<pseudo-file>", "", "", "", "",
@@ -444,6 +445,11 @@ static char *mksquashfs_text[]={
 		"will stop reading after the first tar file on encountering "
 		"them. This option makes Mksquashfs ignore the zero filled "
 		"blocks\n",
+	"-numeric-owner\t\tUse the numeric uid and gid in the tarfile rather "
+		"than the user name or group name.  This is useful where the "
+		"user name or group name maps to a different uid or gid on the "
+		"system where Mksquashfs is being run, and this remapping "
+		"behaviour is not wanted\n",
 	"\n", "Expert options (these may make the filesystem unmountable):",
 	"\n",
 	"-stream\t\t\toutput the filesystem to STDOUT rather than to a file."
@@ -569,18 +575,18 @@ static char *mksquashfs_text[]={
 	"  1\tFatal errors occurred, Mksquashfs aborted and did not generate a "
 		"filesystem (or update if appending).\n",
 	"\n","See also (extra information elsewhere):", "\n",
-	"The README for the Squashfs-tools 4.7.4 release, describing the "
+	"The README for the Squashfs-tools 4.7.5 release, describing the "
 		"new features can be read here https://github.com/plougher/"
-		"squashfs-tools/blob/master/Documentation/4.7.4/README.md\n",
+		"squashfs-tools/blob/master/Documentation/4.7.5/README.md\n",
 	"\nThe MKSQUASHFS usage guide can be read here https://github.com/"
-		"plougher/squashfs-tools/blob/master/Documentation/4.7.4/"
+		"plougher/squashfs-tools/blob/master/Documentation/4.7.5/"
 		"USAGE-MKSQUASHFS.md\n",
 	"\nThe CHANGELOG for Squashfs tools can be read here "
 		"https://github.com/plougher/squashfs-tools/blob/master/"
 		"CHANGES.md\n",
 	"\nThe ACTIONS-README for the actions subsystem can be read here "
 		"https://github.com/plougher/squashfs-tools/blob/master/"
-		"Documentation/4.7.4/ACTIONS-README.md\n",
+		"Documentation/4.7.5/ACTIONS-README.md\n",
 	NULL
 };
 
@@ -687,6 +693,11 @@ static char *sqfstar_text[]={
 		"directory group to <group>, rather than the group of the "
 		"user running Sqfstar.  <group> can be either an integer gid "
 		"or group name.  This also sets the root directory gid\n",
+	"-numeric-owner\t\tUse the numeric uid and gid in the tarfile rather "
+		"than the user name or group name.  This is useful where the "
+		"user name or group name maps to a different uid or gid on the "
+		"system where Sqfstar is being run, and this remapping "
+		"behaviour is not wanted\n",
 	"\n", "Filesystem pseudo options:", "\n",
 	"-p <pseudo-definition>\tadd pseudo file definition.  The definition "
 		"should be quoted.  See section \"Pseudo file definition "
@@ -883,11 +894,11 @@ static char *sqfstar_text[]={
 	"  1\tFatal errors occurred, Sqfstar aborted and did not generate a "
 		"filesystem.\n",
 	"\n","See also (extra information elsewhere):", "\n",
-	"The README for the Squashfs-tools 4.7.4 release, describing the "
+	"The README for the Squashfs-tools 4.7.5 release, describing the "
 		"new features can be read here https://github.com/plougher/"
-		"squashfs-tools/blob/master/Documentation/4.7.4/README.md\n",
+		"squashfs-tools/blob/master/Documentation/4.7.5/README.md\n",
 	"\nThe Sqfstar usage guide can be read here https://github.com/"
-		"plougher/squashfs-tools/blob/master/Documentation/4.7.4/"
+		"plougher/squashfs-tools/blob/master/Documentation/4.7.5/"
 		"USAGE-SQFSTAR.md\n",
 	"\nThe CHANGELOG for Squashfs tools can be read here "
 		"https://github.com/plougher/squashfs-tools/blob/master/"
