@@ -96,16 +96,12 @@ static inline long long get_and_inc_vpos(long long value)
 }
 
 
-static inline int reset_vpos(void)
+static inline void inc_vpos()
 {
 	if(marked_vpos == 0)
 		BAD_ERROR("BUG: Saved write position is empty!\n");
-	else if(marked_vpos == 1)
-		return FALSE;
-	else {
-		set_vpos(marked_vpos);
-		return TRUE;
-	}
+
+	vpos ++;
 }
 
 
